%define	name	Mesa
%define	version	3.1
%define	release	1
%define	serial	2
%define	major	3.1
%define	prefix	/usr
%define	sysconf	/etc/X11

Summary:	A 3-D graphics library with an API very similar to OpenGL.
Name:		%{name}
Version:	%{version}
Release:	%{release}
Serial:		%{serial}
Group:		Development/Libraries
Prefix:		%{prefix}
Copyright:	GPL
Vendor:		Brian Paul <brian_paul@avid.com>
Url:		http://www.ssec.wisc.edu/~brianp/Mesa.html
Source0:	ftp://ftp.mesa.org/mesa/MesaLib-%{version}.tar.gz
Source1:	ftp://ftp.mesa.org/mesa/MesaDemos-%{version}.tar.gz
Buildroot:	/var/tmp/%{name}-%{version}-root

%description
The Mesa 3-D graphics library is a powerful and generic toolset
for creating hardware assisted computer graphics.  To the extent that Mesa
utilizes the OpenGL command syntax or state machine, it is being used with
authorization from Silicon Graphics, Inc.  However, the author (Brian Paul)
makes no claim that Mesa is in any way a compatible replacement for OpenGL
or associated with Silicon Graphics, Inc. Those who want a licensed
implementation of OpenGL should contact a licensed vendor.  However, Mesa is
very similar to OpenGL, and you might find Mesa to be a valid alternative to
OpenGL.

%package	devel
Summary:	The development environment for the Mesa 3-D graphics library.
Group:		Development/Libraries
Serial:		%{serial}
Requires:	%{name} = %{version}
Prefix:		%{prefix}

%description	devel
Mesa-devel contains the static version of the Mesa 3-D graphics
library (a graphics toolkit very similar to Silicon Graphics' OpenGL
graphics utilities toolkit) and includes files needed for development. If
you're going to develop Mesa applications, you'll need to install mesa-devel
along with mesa and possibly mesa-demos. If you're just going to use Mesa,
you don't need to install mesa-devel.


%package	glut
Summary:	The GLUT (OpenGL Utility Toolkit) library for Mesa/OpenGL 3-D graphics.
Group:		Development/Libraries
Serial:		%{serial}
Requires:	%{name} = %{version}
Conflicts:	glut
Prefix:		%{prefix}

%description	glut
Mesa-glut contains the GLUT (OpenGL Utility Toolkit) library.
GLUT is a window system independent toolkit for writing small to
medium-sized OpenGL programs.  OpenGL is a Silicon Graphics, Inc., graphics
utilities toolkit.  Since Mesa (a graphics library) is very similar to
OpenGL, OpenGL programs will work with Mesa.

GLUT is well-suited for learning OpenGL and developing simple OpenGL
applications, but it is not a full-featured toolkit.  If you're interested
in creating large applications requiring sophisticated user interfaces,
you're probably better off using a native window system toolkit like Motif.
If you're interested in learning how to create OpenGL applications or in
creating small and simple OpenGL applications, you should install mesa-glut
along with mesa and possibly mesa-demos.  You may also want to install
mesa-devel, which provides a development environment for Mesa programming.


%package	glut-devel
Summary:	The GLUT (OpenGL Utility Toolkit) development environment for Mesa/OpenGL 3-D graphics.
Group:		Development/Libraries
Serial:		%{serial}
Prefix:		%{prefix}
Conflicts:	glut-devel
Requires:	%{name}-glut = %{version}
Prefix:		%{prefix}

%description	glut-devel
Mesa-glut-devel contains the static version of the GLUT (OpenGL
Utility Toolkit) library and includes files needed for GLUT development.
OpenGL is a Silicon Graphics, Inc., graphics utilities toolkit.  The Mesa
3-D graphics library is a freeware equivalent to OpenGL.  Both OpenGL and
Mesa work with GLUT.

You should install mesa-glut-devel if you want to develop GLUT programs. If
you install mesa-glut-devel, you also need to install mesa, mesa-glut, and
possibly mesa-demos.  If you also want to develop Mesa applications, you
need to also install mesa-devel.

%package	demos
Summary:	You guessed it, demonstration programs for the Mesa 3-D graphics library.
Group:		Development/Libraries
Serial:		%{serial}
Requires:	%{name} = %{version}
Prefix:		%{prefix}

%description	demos
Mesa-demos contains demonstration programs for the Mesa 3-D
graphics library (a graphics toolkit very similar to Silicon Graphics'
OpenGL).  You don't need to install mesa-demos if you're upgrading from a
previous version of Mesa, or if you just aren't interested in the
demonstrations.  If you're new to Mesa, however, you should install them
along with the mesa package.

%prep
%setup -q -n %{name}-%{major} -b 1

%build
%configure --prefix=%{prefix} --sysconfdir=%{sysconf} --enable-static=yes
make
(
	cd widgets-mesa
	%configure --prefix=%{prefix} --sysconfdir=%{sysconf}
	make 
)

# Compiling Demos
for i in 3Dfx book demos images mtdemos samples util xdemos; do
	find $i -type d -name CVS -exec rm -r {} \; || true;
	cd $i
	if [ -e Makefile ]; then
		for m in `grep '^check_PROGRAMS' Makefile | sed -e "s/check_PROGRAMS = //g" -e "s/\\$(SVGA_PROG)//g"`; do
			make $m
		done
	fi
	cd ..
done

%install
if [ -d $RPM_BUILD_ROOT ]; then rm -r $RPM_BUILD_ROOT ; fi
mkdir -p $RPM_BUILD_ROOT

make prefix=$RPM_BUILD_ROOT%{prefix} sysconfdir=$RPM_BUILD_ROOT%{sysconf} install

mkdir -p $RPM_BUILD_ROOT%{prefix}/man/man3
(
	cd widgets-mesa
	make prefix=$RPM_BUILD_ROOT%{prefix} install
	chmod 644 $RPM_BUILD_ROOT%{prefix}/man/man3/*
	gzip -9 $RPM_BUILD_ROOT%{prefix}/man/man3/*
)

# Installing Demos
mkdir -p $RPM_BUILD_ROOT%{prefix}/lib/Mesa-%{major}
for i in 3Dfx book demos images mtdemos samples util xdemos; do
	cp -dpr $i $RPM_BUILD_ROOT%{prefix}/lib/Mesa-%{major};
done

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%clean
if [ -d $RPM_BUILD_ROOT ]; then rm -r $RPM_BUILD_ROOT ; fi

%files
%defattr(-,root,root)
%doc docs/*
%config(noreplace) %{sysconf}/mesa.conf
%ifnarch ppc
%{prefix}/lib/libGL*.so.*
%else
%{prefix}/lib/libGL*.a
%endif

%files devel
%defattr(-,root,root)
%ifnarch ppc
%{prefix}/lib/libGL*.so
%{prefix}/lib/libGL*.a
%{prefix}/lib/libMesaGLw.a
%endif
%dir %{prefix}/include/GL
%{prefix}/include/GL/GLw*.h
%{prefix}/include/GL/Mesa*.h
%{prefix}/include/GL/gl.h
%{prefix}/include/GL/gl_mangle.h
%{prefix}/include/GL/glu.h
%{prefix}/include/GL/glu_mangle.h
%{prefix}/include/GL/glx.h
%{prefix}/include/GL/glx_mangle.h
%{prefix}/include/GL/*mesa*.h
%{prefix}/man/man3/*

%files glut
%defattr(-,root,root)
%ifnarch ppc
%{prefix}/lib/libglut.so.*
%else
%{prefix}/lib/libglut.a
%endif

%files glut-devel
%defattr(-,root,root)
%ifnarch ppc
%{prefix}/lib/libglut.so
%{prefix}/lib/libglut.a
%endif
%{prefix}/include/GL/glut.h

%files demos
%defattr(-,root,root)
%dir %{prefix}/lib/Mesa-%{major}
%{prefix}/lib/Mesa-%{major}/util
%{prefix}/lib/Mesa-%{major}/3Dfx
%{prefix}/lib/Mesa-%{major}/book
%{prefix}/lib/Mesa-%{major}/demos
%{prefix}/lib/Mesa-%{major}/images
%{prefix}/lib/Mesa-%{major}/mtdemos
%{prefix}/lib/Mesa-%{major}/samples
%{prefix}/lib/Mesa-%{major}/xdemos

%changelog
* Fri Dec 17 1999 Ryan Weaver <ryanw@infohwy.com>
  [Mesa-3.1-1]
- added demos/gloss.c
- added xdemos/glxdpyinfo.c
- added GLX_ARB_get_proc_address extension
- several vertex array bug fixes
- overlapping glCopyPixels with pixel zooming now works
- glXUseXFont() bitmaps were vertically shifted by one pixel

* Mon Sep 27 1999 Ryan Weaver <ryanw@infohwy.com>
  [Mesa-3.1beta3-1]
- New:
- optimized glAccum function
- optimized 24bpp rendering in XMesa driver
- GLU 1.2 polygon tessellator
- Ongoing optimization of transformation code in Mesa and the 
  FX driver.

- Bug Fixes:
- glGetTexLevelParameter wasn't fully implemented
- glXUseXFont now handles multi-byte fonts
- glIsEnabled(GL_TEXTURE_2D / 3D) returned wrong result
- alpha channel of blending points, lines was sometimes incorrect

- Changes:
- New library names:  "libGL" instead of "libMesaGL"
- New library numbering: libGL.so.1.2.310
- New subdirectories:  docs/ and bin/
- New Makefile-system (autoconf,automake,libtool)

* Tue Jun  1 1999 Ryan Weaver <ryanw@infohwy.com>
  [Mesa-3.1beta2-2]
- Forgot to include some header files. :(

* Thu May 27 1999 Ryan Weaver <ryanw@infohwy.com>
  [Mesa-3.1beta2-1]
- New:
- multi-textured points and lines (mjk@nvidia.com)
- optimized 24bpp X rendering (bernd.paysan@gmx.de)
- added allegro support (bernie-t@geocities.com)
- cleaned-up Windows-related stuff (Ted Jump)
- minor stereo changes (KendallB@scitechsoft.com)
- new BeOS driver which implements BGLView class
- new Direct3D driver (see src/D3D)
- more efficient filled gluCylinder() function
- utilities:  util/showbuffer.[ch] and util/glstate.[ch]
- fixed some IRIX compiler warnings
- added support for building Mesa in XFree86 with
    SGI's GLX (kevin@precisioninsight.com)
- Bug fixes:
- a variety of Windows/Mesa bug fixes (mjk@nvidia.com)
- packed pixel images weren't unpacked correctly
- patches some win32 files in GLUT (mjk@nvidia.com)
- glTexImage[123]D() didn't accept internalFormat == GL_COLOR_INDEX
- fixed lighting bug in Keith's new shading code
- fixed texture segfault seen in Lament screensaver
- fixed miscellaneous low-memory bugs
- glClear(GL_COLOR_BUFFER_BIT) with RGBA or CI masking was broken
- GL_LINEAR sampling of 3D textures was broken
- fixed SVR4 'cc' compiler macro problem (dawes@xfree86.org)
- added GL_TEXTURE_PRIORITY fix (keithh@netcomuk.co.uk)
- fixed wide point and wide line conformance bugs (brianp)
- Changes:
- some device driver changes (see src/dd.h)
- new copyright on core Mesa code

* Thu Feb  4 1999 Ryan Weaver <ryanw@infohwy.com>
  [Mesa-3.1beta1-5]
- Attempt to make packages relocatable.

* Wed Dec 16 1998 Ryan Weaver <ryanw@infohwy.com>
  [Mesa-3.1beta1-4]
- Updated Specfile to conform to Red Hat Contrib|Net.

* Tue Dec 15 1998 Ryan Weaver <ryanw@infohwy.com>
  [Mesa-3.1beta1-3]
- Split Packages.
- Added stuff from rawhide Mesa-3.0 spec file.
